@@ -23,11 +23,11 @@ e3 <- unname(sapply(
         as.double))
 
 # test
-expect_equal(parse.elapsed.time(t0), e0)
-expect_equal(parse.elapsed.time(t1), e0)
-expect_equal(parse.elapsed.time(t2), e1)
-expect_equal(parse.elapsed.time(t3), e1)
-expect_equal(parse.elapsed.time(t4), e2)
-expect_equal(parse.elapsed.time(t5), e2)
-expect_equal(parse.elapsed.time(t6), e2)
-expect_equal(parse.elapsed.time(t7), e3)
+expect_equal(provParseR:::parse.elapsed.time(t0), e0)
+expect_equal(provParseR:::parse.elapsed.time(t1), e0)
+expect_equal(provParseR:::parse.elapsed.time(t2), e1)
+expect_equal(provParseR:::parse.elapsed.time(t3), e1)
+expect_equal(provParseR:::parse.elapsed.time(t4), e2)
+expect_equal(provParseR:::parse.elapsed.time(t5), e2)
+expect_equal(provParseR:::parse.elapsed.time(t6), e2)
+expect_equal(provParseR:::parse.elapsed.time(t7), e3)
